==> haskell-wai-websockets-3.0.1.1-20-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-wai-websockets.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-websockets
version: 3.0.1.1
id: wai-websockets-3.0.1.1-65ECbItFG3pIDOepHTxHZl
key: wai-websockets-3.0.1.1-65ECbItFG3pIDOepHTxHZl
license: MIT
maintainer: michael@snoyman.com
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: Provide a bridge between WAI and the websockets package.
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-websockets>.
category: Web, Yesod
author: Michael Snoyman, Jasper Van der Jeugt, Ting-Yen Lai
exposed: True
exposed-modules:
    Network.Wai.Handler.WebSockets
abi: 1fca7184c7ad6cdab478c0ce91d3af0b
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/wai-websockets-3.0.1.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/wai-websockets-3.0.1.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/wai-websockets-3.0.1.1
hs-libraries: HSwai-websockets-3.0.1.1-65ECbItFG3pIDOepHTxHZl
depends:
    base-4.9.0.0 blaze-builder-0.4.0.2-J9puUMdRFvA3rt0D0pNg3S
    bytestring-0.10.8.1 case-insensitive-1.2.0.10-1SnYCB9JRtzhTT2S8jwYb
    http-types-0.9.1-3nvMCSru4dgGbycKqlKoUe
    network-2.6.3.2-GMjPV5zpIjuBSljTanWiH transformers-0.5.2.0
    wai-3.2.1.1-OfWV8JQuvWB8nxi8pXkD1
    websockets-0.10.0.0-BXerGWL498j27MDFk0dfYU
haddock-interfaces: /usr/share/doc/haskell-wai-websockets/html/wai-websockets.haddock
haddock-html: /usr/share/doc/haskell-wai-websockets/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-websockets-3.0.1.1-21-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-wai-websockets.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-websockets
version: 3.0.1.1
id: wai-websockets-3.0.1.1-8xZGtxXKVvoFTOl9hLs5mi
key: wai-websockets-3.0.1.1-8xZGtxXKVvoFTOl9hLs5mi
license: MIT
maintainer: michael@snoyman.com
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: Provide a bridge between WAI and the websockets package.
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-websockets>.
category: Web, Yesod
author: Michael Snoyman, Jasper Van der Jeugt, Ting-Yen Lai
exposed: True
exposed-modules:
    Network.Wai.Handler.WebSockets
abi: 1fef3dfffcf79538756eb601690f371d
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/wai-websockets-3.0.1.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/wai-websockets-3.0.1.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/wai-websockets-3.0.1.1
hs-libraries: HSwai-websockets-3.0.1.1-8xZGtxXKVvoFTOl9hLs5mi
depends:
    base-4.9.0.0 blaze-builder-0.4.0.2-J9puUMdRFvA3rt0D0pNg3S
    bytestring-0.10.8.1 case-insensitive-1.2.0.10-1SnYCB9JRtzhTT2S8jwYb
    http-types-0.9.1-3nvMCSru4dgGbycKqlKoUe
    network-2.6.3.2-GMjPV5zpIjuBSljTanWiH transformers-0.5.2.0
    wai-3.2.1.1-OfWV8JQuvWB8nxi8pXkD1
    websockets-0.10.0.0-4xWvoPZ859nEsbQ1TL0hfR
haddock-interfaces: /usr/share/doc/haskell-wai-websockets/html/wai-websockets.haddock
haddock-html: /usr/share/doc/haskell-wai-websockets/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
